Crate tacacs_plus

Crate tacacs_plus 

tacacs-plus

Rust client implementation for the TACACS+ (RFC8907) protocol.

Re-exports

pub use tacacs_plus_protocol as protocol;

Structs

AccountingResponse
The response from a successful TACACS+ accounting operation.
AccountingTask
An ongoing task whose status is tracked via TACACS+ accounting.
Argument
An argument in the TACACS+ protocol, which exists for extensibility.
AuthenticationResponse
A server response from an authentication session.
AuthorizationResponse
A TACACS+ server response from an authorization session.
Client
A TACACS+ client.
ContextBuilder
Builder for SessionContext objects.
FieldText
A wrapper for &str that is checked to be printable ASCII, which is defined as not containing control characters in RFC8907 section 3.7.
SessionContext
Some information associated with all sessions, regardless of the action.

Enums

AuthenticationMethod
The method used to authenticate to the TACACS+ client.
AuthenticationType
The type of authentication used for a given session.
ClientError
An error during a TACACS+ exchange.
ResponseStatus
The final status returned by a server during a TACACS+ session.

Type Aliases

ConnectionFactory
An async factory that returns connections used by a Client.
ConnectionFuture
A (pinned, boxed) future that returns a client connection or an error, as returned from a ConnectionFactory.