ConnectionFuture

Type Alias ConnectionFuture 

pub type ConnectionFuture<S> = Pin<Box<dyn Future<Output = Result<S>> + Send>>;
A (pinned, boxed) future that returns a client connection or an error, as returned from a ConnectionFactory.

This is roughly equivalent to the BoxFuture type in the futures crate, but without the lifetime parameter.

Aliased Type

pub struct ConnectionFuture<S> { /* private fields */ }