Re-exports
pub use tacacs_plus_protocol as protocol;
Structs
- Accounting
Response - The response from a successful TACACS+ accounting operation.
- Accounting
Task - An ongoing task whose status is tracked via TACACS+ accounting.
- Argument
- An argument in the TACACS+ protocol, which exists for extensibility.
- Authentication
Response - A server response from an authentication session.
- Authorization
Response - A TACACS+ server response from an authorization session.
- Client
- A TACACS+ client.
- Context
Builder - Builder for
SessionContextobjects. - Field
Text - A wrapper for
&strthat is checked to be printable ASCII, which is defined as not containing control characters in RFC8907 section 3.7. - Session
Context - Some information associated with all sessions, regardless of the action.
Enums
- Authentication
Method - The method used to authenticate to the TACACS+ client.
- Authentication
Type - The type of authentication used for a given session.
- Client
Error - An error during a TACACS+ exchange.
- Response
Status - The final status returned by a server during a TACACS+ session.
Type Aliases
- Connection
Factory - An async factory that returns connections used by a
Client. - Connection
Future - A (pinned, boxed) future that returns a client connection or an error, as returned from a
ConnectionFactory.